.. include:: /extras.rst.txt
.. highlight:: rst
.. index:: how-to-index ; Index


.. _how-to-index:
======
How-To
======


.. toctree::
   :hidden:
   :titlesonly:

   quickstart.rst
   how-to-tag-parser
   how-to-custom-list
   how-to-contributing
   how-to-tag-sync
